/*
  ***************************************************************************
  File:    LOAD.C
  Project: Developer's libraries for Comtrol serial controllers.
  Purpose: This is the loader code for API/SSCI.  A control program
           is downloaded to the controller and started based on the 
           parameters in the "config.dat" file.  This is a text file that
           allows the user to select the following:

           o Base I/O Address of the controller
           o Dual Port Memory address (16k) of the controller
           o IRQ (Interrupt Vector) of the controller
           o 8 or 16 bit data transfers for the controller
           o Starting address on the controller for the control program
           o 'Y' or 'N' on whether to start Turbo Debug
           o The name of the control program
           o The number of lines for this controller


  Company: Comtrol Corporation
  Author:  Jerry Medin
  ***************************************************************************
  Copyright 1993 Comtrol Corporation. All rights reserved.
  Subject to developers license agreement.
  ***************************************************************************
  Release: 1.0 - 6/1/93 - Jerry Medin
           Original release
*/

#include <stdio.h>
#include "s_types.h"
#include "s_ssci.h"
#include "s_api.h"


static CF_T CfgFileData;    /* structure to hold all controller information */

/*
 *****************************************************************************
  Function: Main

  Purpose:  Call the appropriate API functions to read the configuration
            file, pass the information along to initialize all controllers, 
            download and start all controllers.

 *****************************************************************************
*/

main()
{
  int i;


  /* Read the Configuration file */

  aaReadConfigFile("config.dat",&CfgFileData);


  /* Initialize the controller from the "config.dat" file */

  if (aaInitControllers(&CfgFileData) == -1)
     return(0);


  /* Download and start the control program */
     

  for (i=0; i<CfgFileData.NumCtlrs; i++)
  {
     aaDownloadCP(i,CfgFileData.CfCtl[i].CtlPgmName,
                  CfgFileData.CfCtl[i].CPStartAddr,
                  CfgFileData.CfCtl[i].TdFlag);
     sStartCP(i,CfgFileData.CfCtl[i].NumLines);
  }

	return (0);

} /* end main */



